@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 #<<<  NO perltidy - must be all on one line
-use version; our $VERSION = version->new('0.10');
+use version; our $VERSION = version->new('0.4');
 #>>>
 use Carp qw(confess);
 use English qw( -no_match_vars );
@@ -12,15 +12,10 @@ use File::Slurp qw( slurp );
 use LWP::UserAgent;
 use HTTP::Request;
 use Moose;
-use Moose::Util::TypeConstraints;
 use WWW::GoDaddy::REST::Resource;
 use WWW::GoDaddy::REST::Schema;
 use WWW::GoDaddy::REST::Util qw(abs_url json_encode json_decode is_json );
 
-subtype 'PositiveInt', as 'Int', where { $_ > 0 };
-
-no Moose::Util::TypeConstraints;
-
 my $JSON_MIME_TYPE = 'application/json';
 
 has 'url' => (
@@ -30,14 +25,6 @@ has 'url' => (
     documentation => 'Base url of the REST service'
 );
 
-has 'timeout' => (
-    is            => 'rw',
-    isa           => 'PositiveInt',
-    required      => 1,
-    default       => 10,
-    documentation => 'Timeout in seconds for HTTP calls'
-);
-
 has 'basic_username' => (
     is            => 'rw',
     isa           => 'Str',
@@ -148,9 +135,8 @@ sub http_request_schemas_json {
 }
 
 sub http_request_as_resource {
-    my ( $self, $method, $url, $content, $http_opts ) = @_;
-    my ( $struct_from_json, $http_response )
-        = $self->http_request( $method, $url, $content, $http_opts );
+    my ( $self, $method, $url, $content ) = @_;
+    my ( $struct_from_json, $http_response ) = $self->http_request( $method, $url, $content );
 
     my $resource = WWW::GoDaddy::REST::Resource->new_subclassed(
         {   client        => $self,
@@ -173,10 +159,7 @@ sub http_request_as_resource {
 
 sub http_request {
     my $self = shift;
-    my ( $method, $uri, $perl_data, $http_opts ) = @_;
-
-    $http_opts ||= {};
-    $http_opts->{timeout} ||= $self->timeout;
+    my ( $method, $uri, $perl_data ) = @_;
 
     $uri = abs_url( $self->url, $uri );
 
@@ -193,20 +176,7 @@ sub http_request {
 
     my $request = $self->build_http_request( $method, $uri, $headers, $content );
 
-    my $response = eval {
-        local $SIG{ALRM} = sub { die("alarm\n") };
-        alarm $http_opts->{timeout};
-        return $self->user_agent->request($request);
-    };
-    alarm 0;
-    if ( my $e = $@ ) {
-        if ( $e eq "alarm\n" ) {
-            confess("timed out while calling '$method' '$uri'");
-        }
-        else {
-            confess($e);
-        }
-    }
+    my $response      = $self->user_agent->request($request);
     my $response_text = $response->content;
 
     my $content_data;
@@ -315,11 +285,7 @@ There are two methods that deal with searching: C<query> and C<query_by_id>.
 
 Example:
 
-  # GET /v1/how_the_schema_defines/the_resource/url/id
-  $resource = $client->query_by_id('the_schema','the_id');
-
-  # GET /v1/how_the_schema_defines/the_resource/url/id?other=param
-  $resource = $client->query_by_id('the_schema','the_id', { other => 'param' });
+  $resource = $client->query_by_id('schema_name','id');
 
 =head2 SEARCH WITH FILTER
 
@@ -366,10 +332,6 @@ Assumed Equality Example:
     }
   );
 
-Pass Through to query_by_id VS Search
-
-  $resource = $client->query( 'the_schema_name', 'id' );
-
 =head1 ATTRIBUTES
 
 Attributes can be provided in the C<new> method and have corresponding
@@ -477,44 +439,28 @@ the HTTP response code in the resultant resource on your own.
 
 Search for a list of resources given a schema name and a filter.
 
-If the second parameter is a scalar, is assumes you are not searching but rather
-trying to load a specific resource.
-
-See the documentation for C<query_by_id>.
-
-In scalar context, this returns a L<Collection|WWW::GoDaddy::REST::Collection>
+In scalar context, this returns a L<WWW::GoDaddy::REST::Collection>
 object.
 
-In list context, this returns a list of L<Resource|WWW::GoDaddy::REST::Resource>
+In list context, this returns a list of L<WWW::GoDaddy::REST::Resource>
 objects (or subclasses).
 
-
 Example:
 
   @items      = $client->query('schema_name',{ 'field' => 'value' });
   $collection = $client->query('schema_name',{ 'field' => 'value' });
-  $item       = $client->query('schema_name','1234');
-  $item       = $client->query('schema_name','1234',{ 'field' => 'value' });
-  $item       = $client->query('schema_name','1234',undef,{ timeout => 15 });
 
 See L<"SEARCHING AND FILTERS"> for more information.
 
 =item query_by_id
 
-Search for a single instance of a resource by its primary id.  Optionally
-specify a hash for additional query params to append to the resource URL.
+Search for a single instance of a resource by its primary id.
 
-This returns a L<Resource|WWW::GoDaddy::REST::Resource> (or a subclass).
+This returns a L<WWW::GoDaddy::REST::Resource> (or a subclass).
 
 Example:
 
-  # GET /v1/how_the_schema_defines/the_resource/url/the_id
   $resource = $client->query_by_id('the_schema','the_id');
-  $resource = $client->query_by_id('the_schema','the_id',undef,{ timeout => 15 });
-
-  # GET /v1/how_the_schema_defines/the_resource/url/the_id?other=param
-  $resource = $client->query_by_id('the_schema','the_id', { other => 'param' });
-  $resource = $client->query_by_id('the_schema','the_id', { other => 'param' }, { timeout => 15 });
 
 =item create
 
@@ -526,7 +472,6 @@ This returns a L<WWW::GoDaddy::REST::Resource> (or a subclass).
 Example:
 
    $car = $client->create('autos', { 'make' => 'Tesla', 'model' => 'S' });
-   $car = $client->create('autos', { 'make' => 'Tesla', 'model' => 'S' }, { timeout => 30 });
 
 =item schema
 
